#
# spec file for package kbuild
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _svnrev 3427
Name:           kbuild
Version:        0.1.9998svn%{_svnrev}
Release:        2.2
Summary:        Framework for writing simple makefiles for complex tasks
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://svn.netlabs.org/kbuild
Source0:        %{name}-%{version}.tar.bz2
Patch0:         kbuild-man.diff
Patch2:         kbuild-dummy_noreturn.diff
Patch5:         kbuild-pthread.diff
Patch6:         kbuild-timestamps.diff
Patch7:         kbuild-armv7l.diff
Patch8:         kbuild-wrong-memset.patch
Patch9:         ppc64le.patch
Patch10:        aarch64.patch
Patch13:        glob-lstat.patch
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  byacc
BuildRequires:  flex
BuildRequires:  libacl-devel
BuildRequires:  makeinfo
BuildRequires:  readline-devel

%description
The goals of the kBuild framework:

 - Similar behavior across all supported platforms
 - Flexibility, don't create unnecessary restrictions preventing ad-hoc
   solutions
 - Makefiles can be simple to write and maintain
 - One configuration file for a subtree automatically included
 - Target configuration templates as the primary mechanism for makefile
   simplification
 - Tools and SDKs for helping out the templates with flexibility
 - Non-recursive makefile method by using sub-makefiles

%prep
%setup -q
%patch -P 0
%patch -P 2
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8 -p1
%patch -P 9 -p1
%patch -P 10 -p1
%patch -P 13 -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
cat > SvnInfo.kmk << EOF
KBUILD_SVN_REV := %{_svnrev}
KBUILD_SVN_URL := http://svn.netlabs.org/repos/kbuild/trunk
EOF
kBuild/env.sh --full make -f bootstrap.gmk SRCDIR=`pwd`
kBuild/env.sh kmk rebuild PATH_INS=`pwd`
pod2man -c 'kBuild for SUSE Linux' -r kBuild-%{version} kmk.pod > kmk.1

%install
kBuild/env.sh kmk NIX_INSTALL_DIR=%{_prefix} BUILD_TYPE=release PATH_INS=%{buildroot} LDFLAGS=-Wl,--as-needed install
install -m 644 -D kmk.1 %{buildroot}/%{_mandir}/man1/kmk.1
#remove execute flag, if occurs
chmod a-x %{buildroot}/%{_datadir}/kBuild/*/*kmk
rm -r %{buildroot}%{_datadir}/doc/kBuild-0.1.9998

%files
%license COPYING
%license kBuild/doc/COPYING-FDL-1.3
%doc ChangeLog
%doc kBuild/doc/QuickReference-kmk.*
%{_bindir}/*
%{_mandir}/man1/kmk.1%{?ext_man}
%{_datadir}/kBuild

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Sep  1 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add byacc to BuildRequires fixes problems with bison 3.7 (bsc#1175268)
* Mon Aug 31 2020 Dirk Mueller <dmueller@suse.com>
- update to svn3427:
  * 3 years of changes, see http://trac.netlabs.org/kbuild/timeline
- remove patches:
  gcc10-fno-common-fix.patch, glob-interface.patch,
  use-alloca.patch, kbuild-gcc7.patch, kbuild-glob.patch,
  strsignal.patch: upstream or obsolete
* Mon Aug 31 2020 Andreas Schwab <schwab@suse.de>
- strsignal.patch: use strsignal instead of sys_siglist (bsc#1175268)
* Fri Apr  3 2020 Martin Liška <mliska@suse.cz>
- Add gcc10-fno-common-fix.patch in order to fix boo#1160274.
* Tue Dec 17 2019 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
* Sun Feb 10 2019 Larry Finger <Larry.Finger@gmail.com>
- Returned changelist back to a %%doc.
* Sun Feb 10 2019 Larry Finger <Larry.Finger@gmail.com>
- Changed spec file to require readline-devel, not a specific libreadline version.
  Thanks to Jan Engelhardt <jengelh@inai.de> for suggestion.
* Sat Feb  9 2019 Larry Finger <Larry.Finger@gmail.com>
- Add libreadline6 to the BuildRequires list.
- Changed %%doc to %%license for COPYING as directed by osc.
* Tue Feb 20 2018 schwab@suse.de
- glob-lstat.patch: Do not assume glibc glob internals
- glob-interface.patch: Support GLIBC glob interface version 2
* Tue Feb 20 2018 dmueller@suse.com
- add use-alloca.patch (bsc#1079838)
* Sun Oct 22 2017 Larry.Finger@lwfinger.net
- Update to version 0.1.9998svn3110. VirtualBox 5.2.0 needs this one to build.
  Changes detailed in upstream url from svn 2815 to 3110.
- Rebased patches
- Removed test for openSUSE 12.3 from spec file.
* Wed May 17 2017 dimstar@opensuse.org
- Add kbuild-gcc7.patch: Fix build with GCC7 (boo#1039375): we also
  need the definition of strlcpy on Linux; only *BSD has this by
  default.
* Sat Nov 12 2016 ro@suse.de
- add aarch64.patch
* Thu Jul 21 2016 luizluca@tre-sc.jus.br
- Update to version 0.1.9998svn2814:
  Changes detailed in upstream url from svn 2784 to 2814.
  http://trac.netlabs.org/kbuild/changeset?old_path=%%2F&old=2784&new_path=%%2F&new=2814
- Rebased patches:
  ppc64le.patch
* Fri Jun 26 2015 normand@linux.vnet.ibm.com
- Update to version 0.1.9998svn2784:
  many changes detailed in upstream url from svn 2720 to 2784.
  http://trac.netlabs.org/kbuild/timeline?from=2015-06-26&daysback=365
  http://trac.netlabs.org/kbuild/changeset?old_path=%%2F&old=2784&new_path=%%2F&new=2720
- Dropped patches:
  kbuild-kmk-makefile-am.patch
- Rebased patches:
  kbuild-glob.patch
  ppc64le.patch
  kbuild-timestamps.diff
  kbuild-pthread.diff
- All above changes allow to build package for ppc64/ppc64le archs
* Fri Jun 12 2015 dvaleev@suse.com
- Rework ppc64le patch. Previous one was totally wrong.
- Modified patch ppc64le.patch
* Fri Jan 17 2014 speilicke@suse.com
- Update to version 0.1.9998svn2720:
  + VirtualBox-4.3.6 requires revision 2689 or later
- Dropped patches:
  + warnings.diff (obsolete)
  + glibc-2.10.diff (solved differently upstream)
  + kbuild-func_missing_args.diff (obsolete)
- Rebased patches:
  + kbuild-pthread.diff (only offset)
  + kbuild-timestamps.diff (only offset)
  + kbuild-armv7l.diff (only offset)
  + kbuild-dummy_noreturn.diff (manually)
- Add patches:
  + kbuild-glob.patch: Include local glob implementation
  + kbuild-kmk-makefile-am.patch: Fix wrong file list
* Mon Dec  2 2013 dvaleev@suse.com
- added patches:
  * ppc64le.patch
- Make ppc64le architecture known
* Fri Apr 26 2013 mmeister@suse.com
- Added makeinfo BuildRequire to fix build with new automake
* Fri Sep 28 2012 seife+obs@b1-systems.com
- update to svn rev 2577
  rev 2577 is minimum required by virtualbox-4.2.0, but newer
  versions do not work (tested with rev 2662)
* Tue Dec 27 2011 idonmez@suse.com
- Fix wrong size parameter in memset call
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Oct  3 2011 joop.boonen@opensuse.org
- Added a patch to support armv7l
* Tue Aug 23 2011 mseben@gmail.com
- updated to 0.1.9998 (svn revision 2538) in order to build
  virtualbox 4.1.2, for changes check http://svn.netlabs.org/kbuild/timeline
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Sun May 31 2009 dmueller@suse.de
- fix build against glibc 2.10
* Mon Apr 20 2009 mseben@suse.cz
- updated to 0.1.5svn2336
  - updated Maintenance.kmk with a patch variable.
  - backported 2320: qt3.kmk: Fixed PATH_SDK_QT3_LIB detection
  - backported 2318: footer.kmk: No need to apply defpath to 2_OBJS
    wholesale fashion, the handler(s) will do this
  - backported 2316: *WATCOM*: Fixed RC commands.
  - backported 2283: incdep.c: If we find LD_PRELOAD on linux, assume
  the worst and disable threading
  - backported 2277: kmk: Testcase for the $(if-expr 1==2,) crash.
  - backported 2276: kmk: Do not crash if is missing the 3rd
  argument, it is supposed to be optional...
  - backported 2275: TAR.kmk,TARGZ.kmk,TARBZ2.kmk: Fixes and
  additions (BZ2).
  - backported 2274: footer.kmk,header.kmk: Enhanced tools inhertiance
  - backported 2273: VCC80X86: TOOL_VCC80X86_LINK_LIBRARY_OUTPUT_OUTPUT
  - > TOOL_VCC80X86_LINK_LIBRARY_OUTPUT_MAYBE. oops
  - backported 2272: qt4.kmk: Look for the QT4 tools in the
  alternative tools tree (x86) when present (amd64).
  - backported 2271: header.kmk: KBUILD_DEVTOOLS, KBUILD_DEVTOOLS_TRG,
  KBUILD_DEVTOOLS_HST, KBUILD_DEVTOOLS_TRG_ALT and KBUILD_DEVTOOLS_HST_ALT.
- updated func_missing_args.diff
* Wed Feb 11 2009 dmueller@suse.de
- merge with openSUSE Factory:
  * remove macro from Version line again. Although it is nice,
  it causes other problems
* Thu Jan 29 2009 suse-tux@gmx.de
- create SvnInfo.kmk before the build starts
* Thu Jan 29 2009 suse-tux@gmx.de
- updated to 0.1.5svn2270
- use macros inside the spec
- updated Patch1 (warnings.diff) - some parts are already fixed upstream
- removed Patch3 (kbuild-buildfix.diff) because it isn't needed anymore
- added Patch3 (kbuild-func_missing_args.diff) to prevent some compiler warnings
* Thu Dec 25 2008 suse-tux@gmx.de
- updated to 0.1.4svn2112
- added kbuild-buildfix.diff
* Tue Oct 14 2008 meissner@suse.de
- fixed an implicit getcwd()
* Thu Sep 25 2008 mkudlvasr@suse.cz
- merge into openSUSE Factory
* Thu Sep 18 2008 suse-tux@gmx.de
- added Patch2 (kbuild-dummy_noreturn.diff) in order to make the build checks happy
* Sun Sep 14 2008 suse-tux@gmx.de
- update to 0.1.3svn1785
* Sat Sep 13 2008 suse-tux@gmx.de
- update to 0.1.3svn1775
- removed kbuild-r1599_KBUILD_SVN_INFO_KMK-fix.diff
* Tue May  6 2008 dmueller@suse.de
- fix uninit return values
* Sun May  4 2008 suse-tux@gmx.de
- update to svn1599 in order to build virtualbox-ose 1.6.0
- added kbuild-r1599_KBUILD_SVN_INFO_KMK-fix.diff
- start the bootstrap with kBuild/env.sh --full because this sets all required
  variables automagically
* Mon Apr  7 2008 dmueller@suse.de
- fix crash on x86_64
* Wed Apr  2 2008 dmueller@suse.de
- Initial package (0.1.2svn1480)
